@@ -1,9 +1,10 @@
 use strict;
 use warnings;
+# ABSTRACT: a tolerance "m (-l or +n)"
 
 package
   Number::Tolerant::Type::offset;
-use base qw(Number::Tolerant::Type);
+use parent qw(Number::Tolerant::Type);
 
 sub construct { shift;
   {
@@ -51,15 +52,16 @@ sub valid_args {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
 
-Number::Tolerant::Type::offset
+Number::Tolerant::Type::offset - a tolerance "m (-l or +n)"
 
 =head1 VERSION
 
-version 1.701
+version 1.702
 
 =head1 AUTHOR
 
@@ -73,4 +75,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
